package com.magelang.box;

import java.awt.Container;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.beans.Beans;

public class BoxAdapter extends Container {
	private static Dimension empty = new Dimension(0,0);
	private static Dimension dummy = new Dimension(20,20);
	private static Dimension max   = new Dimension(Short.MAX_VALUE,Short.MAX_VALUE);
	private Dimension dim = new Dimension(0,0);
	private boolean fieldStretchVertical   = false;
	private boolean fieldStretchHorizontal = false;
	private boolean fieldShrinkVertical    = false;
	private boolean fieldShrinkHorizontal  = false;
	protected transient java.beans.PropertyChangeSupport propertyChange;
	private float fieldAlignmentX = 0.5f;
	private float fieldAlignmentY = 0.5f;
public BoxAdapter() {
	super();
	setLayout(new GridLayout(1, 0));
}
/**
 * The addPropertyChangeListener method was generated to support the propertyChange field.
 */
public synchronized void addPropertyChangeListener(java.beans.PropertyChangeListener listener) {
	getPropertyChange().addPropertyChangeListener(listener);
}
/**
 * The firePropertyChange method was generated to support the propertyChange field.
 */
public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
	getPropertyChange().firePropertyChange(propertyName, oldValue, newValue);
}
/**
 * Gets the alignmentX property (float) value.
 * @return The alignmentX property value.
 * @see #setAlignmentX
 */
public float getAlignmentX() {
	return fieldAlignmentX;
}
/**
 * Gets the alignmentY property (float) value.
 * @return The alignmentY property value.
 * @see #setAlignmentY
 */
public float getAlignmentY() {
	return fieldAlignmentY;
}
public Dimension getMaximumSize() {
	if (getStretchVertical() && getStretchHorizontal())
		return max;
	Dimension pref = getPreferredSize();
	dim.height = getStretchVertical() ? Short.MAX_VALUE : pref.height;
	dim.width = getStretchHorizontal() ? Short.MAX_VALUE : pref.width;
	return dim;
}
public Dimension getMinimumSize() {
	if (getShrinkVertical() && getShrinkHorizontal())
		return empty;
	Dimension pref = getPreferredSize();
	dim.height = getShrinkVertical() ? 0 : pref.height;
	dim.width = getShrinkHorizontal() ? 0 : pref.width;
	return dim;
}
	public Dimension getPreferredSize() {
		if (Beans.isDesignTime() && getComponentCount() == 0)
			return dummy;
		return super.getPreferredSize();
	}
/**
 * Accessor for the propertyChange field.
 */
protected java.beans.PropertyChangeSupport getPropertyChange() {
	if (propertyChange == null) {
		propertyChange = new java.beans.PropertyChangeSupport(this);
	};
	return propertyChange;
}
public boolean getShrinkHorizontal() {
	return fieldShrinkHorizontal;
}
public boolean getShrinkVertical() {
	return fieldShrinkVertical;
}
public boolean getStretchHorizontal() {
	return fieldStretchHorizontal;
}
public boolean getStretchVertical() {
	return fieldStretchVertical;
}
	public void paint(Graphics g) {
		if (Beans.isDesignTime() && getComponentCount() == 0) {
			Color oldColor = g.getColor();
			g.setColor(Color.red);
			Dimension d = getSize();
			int dx = d.width/5;
			int dy = d.width/5;
			g.drawRect(1,dy,d.width-dx-2,d.height-dy-2);
			g.drawLine(1,dy,dy,1);
			g.drawLine(dy,1, d.width-2,1);
			g.drawLine(d.width-2,1, d.width-2,d.height-dy-2);
			g.drawLine(d.width-2,1, d.width-dx-2,dy);
			g.drawLine(d.width-2,d.height-dy-2, d.width-dx-2,d.height-2);
//			g.drawRect(1,7,12,12);
//			g.drawLine(1,7,7,1);
//			g.drawLine(13,7,19,1);
//			g.drawLine(13,19,19,13);
//			g.drawLine(7,1,19,1);
//			g.drawLine(19,1,19,13);
			g.setColor(oldColor);
		}
		else
			super.paint(g);
	}
/**
 * The removePropertyChangeListener method was generated to support the propertyChange field.
 */
public synchronized void removePropertyChangeListener(java.beans.PropertyChangeListener listener) {
	getPropertyChange().removePropertyChangeListener(listener);
}
/**
 * Sets the alignmentX property (float) value.
 * @param alignmentX The new value for the property.
 * @see #getAlignmentX
 */
public void setAlignmentX(float alignmentX) {
	float oldValue = fieldAlignmentX;
	fieldAlignmentX = alignmentX;
	firePropertyChange("alignmentX", new Float(oldValue), new Float(alignmentX));
}
/**
 * Sets the alignmentY property (float) value.
 * @param alignmentY The new value for the property.
 * @see #getAlignmentY
 */
public void setAlignmentY(float alignmentY) {
	float oldValue = fieldAlignmentY;
	fieldAlignmentY = alignmentY;
	firePropertyChange("alignmentY", new Float(oldValue), new Float(alignmentY));
}
public void setShrinkHorizontal(boolean shrinkHorizontal) {
	fieldShrinkHorizontal = shrinkHorizontal;
}
public void setShrinkVertical(boolean shrinkVertical) {
	fieldShrinkVertical = shrinkVertical;
}
public void setStretchHorizontal(boolean stretchHorizontal) {
	fieldStretchHorizontal = stretchHorizontal;
}
public void setStretchVertical(boolean stretchVertical) {
	fieldStretchVertical = stretchVertical;
}
}